# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# NOTE! THIS FILE IS AUTOMATICALLY GENERATED AND WILL BE
# OVERWRITTEN WHEN PREPARING PACKAGES.
#
# IF YOU WANT TO MODIFY IT, YOU SHOULD MODIFY THE TEMPLATE
# `get_provider_info_TEMPLATE.py.jinja2` IN the `provider_packages` DIRECTORY

def get_provider_info():
    return {
        'package-name': 'apache-airflow-providers-mongo',
        'name': 'MongoDB',
        'description': '`MongoDB <https://www.mongodb.com/what-is-mongodb>`__\n',
        'versions': ['2.3.1', '2.3.0', '2.2.0', '2.1.0', '2.0.0', '1.0.1', '1.0.0'],
        'additional-dependencies': ['apache-airflow>=2.1.0'],
        'integrations': [
            {
                'integration-name': 'MongoDB',
                'external-doc-url': 'https://www.mongodb.com/what-is-mongodb',
                'logo': '/integration-logos/mongo/MongoDB.png',
                'tags': ['software'],
            }
        ],
        'sensors': [
            {'integration-name': 'MongoDB', 'python-modules': ['airflow.providers.mongo.sensors.mongo']}
        ],
        'hooks': [{'integration-name': 'MongoDB', 'python-modules': ['airflow.providers.mongo.hooks.mongo']}],
        'hook-class-names': ['airflow.providers.mongo.hooks.mongo.MongoHook'],
        'connection-types': [
            {'hook-class-name': 'airflow.providers.mongo.hooks.mongo.MongoHook', 'connection-type': 'mongo'}
        ],
    }
